#pragma once

#include <memory>

namespace precice::config {

class ParticipantConfiguration;

using PtrParticipantConfiguration = std::shared_ptr<ParticipantConfiguration>;

} // namespace precice::config
